.. _docs_index:

Raster Loader
=============

The Raster Loader is a tool for loading GIS raster data to standard cloud-based data
warehouses that don't natively support raster data.

You can use this package in two ways:

* As a standalone tool using the :ref:`command line interface <cli>`.
* As a Python library that you can :ref:`import and use in your Python projects
  <python>`.

This documentation contains the following sections:

.. toctree::
   :caption: Using Raster Loader
   :maxdepth: 1

   user_guide/installation
   user_guide/cli
   user_guide/use_with_python
   user_guide/modules/raster_loader

.. toctree::
   :caption: Contributing to Raster Loader
   :maxdepth: 1

   developer_guide/contribute
   developer_guide/roadmap
